export declare class PromiseQueue {
    /** Number of tasks currently in the queue and awaiting completion. */
    private size;
    /** Flag indicating the queue is currently processing tasks. */
    private paused;
    /** Number of tasks currently being executed. */
    private inflight;
    /** Number of promises that may be awaited simultaneously. */
    private readonly concurrency;
    private readonly bucketQueue;
    /** Internal signalling. Used to trigger queue processing. */
    private readonly emitter;
    constructor({ concurrency }?: {
        /** The number of tasks that will be executed concurrently.
         * Note that if concurrency > 1, the queue cannot guarantee FIFO since the tasks' execution times may vary. */
        concurrency?: number;
    });
    /** Pick and execute the highest priority task. */
    private processTasks;
    /** Pause queue execution */
    pause(): void;
    /** Resume queue execution */
    resume(): void;
    /** Whether the task processing is currently paused. */
    isPaused(): boolean;
    /** Returns the number of uncompleted tasks on the queue. */
    getSize(): number;
    /** Add a prioritized task to the queue.
     * Note that a lower priority number means that the task will be prioritized.
     * Ie.: `0` is the highest priority value.
     */
    addTask<T>(priority: number, task: () => Promise<T>): Promise<T>;
}
//# sourceMappingURL=PromiseQueue.d.ts.map